@@ -12,10 +12,9 @@
 {
 @private
 	IBOutlet MyTableTab *playlistsTab;
-	int previousTrackIndexSelected;
 	NSDictionary *fileExtensionsToCodecsDictionary;
 	activeObjects objectToSaveTrack;
-	BOOL trackListIsUpToDate;
+	BOOL trackListUpToDate;
 }
 - (void)loadTracks;
 - (NJBTransactionResult *)downloadTrackList;
@@ -23,6 +22,6 @@
 - (void)copyTrackFromNJB:(Track *)track;
 - (void)replaceTrack:(Track *)replace withTrack:(Track *)new;
 - (void)writeTagToFile:(Track *)track;
-- (BOOL)trackListIsUpToDate;
+- (NJBTransactionResult *)uploadTrack:(Track *)track;
 
 @end
