@@ -18,7 +18,7 @@
 #include <stdlib.h>
 #import "Track.h"
 #include "string.h"
-#include "njbusb.h"
+#include "base.h"
 #include "njb_error.h"
 #import "defs.h"
 #include <sys/stat.h>
@@ -50,6 +50,7 @@ StatusDisplayer *statusDisplayerGlobal;
 	if (self = [super init])
 	{
 		njb = NULL;
+		// 15 is max
 		[self setDebug:0];
 		[self setTurbo:YES];
 	}
@@ -266,20 +267,25 @@ StatusDisplayer *statusDisplayerGlobal;
 		frame = NJB_Songid_Findframe(songtag, FR_TITLE);
 		if (frame != NULL && frame->data.strval != NULL)
 			[track setTitle:[NSString stringWithUTF8String:frame->data.strval]];
+		
 		frame = NJB_Songid_Findframe(songtag, FR_ALBUM);
 		if (frame != NULL && frame->data.strval != NULL)
 			[track setAlbum:[NSString stringWithUTF8String:frame->data.strval]];
+		
 		frame = NJB_Songid_Findframe(songtag, FR_ARTIST);
 		if (frame != NULL && frame->data.strval != NULL)
 			[track setArtist:[NSString stringWithUTF8String:frame->data.strval]];
+		
 		frame = NJB_Songid_Findframe(songtag, FR_GENRE);
 		if (frame != NULL && frame->data.strval != NULL)
 			[track setGenre:[NSString stringWithUTF8String:frame->data.strval]];
+		
 		// this is not used: we don't get extended track info from njb3
 		// njb1 gets it but ignored
 		frame = NJB_Songid_Findframe(songtag, FR_FNAME);
 		if (frame != NULL && frame->data.strval != NULL)
 			[track setFilename:[NSString stringWithUTF8String:frame->data.strval]];
+		
 		frame = NJB_Songid_Findframe(songtag, FR_SIZE);
 		if (frame != NULL)
 		{
@@ -333,7 +339,7 @@ StatusDisplayer *statusDisplayerGlobal;
 		}
 		
 		[track setItemID:songtag->trid];
-		
+
 		frame = NJB_Songid_Findframe(songtag, FR_YEAR);
 		if (frame != NULL)
 		{
@@ -441,6 +447,7 @@ StatusDisplayer *statusDisplayerGlobal;
 
 - (NJBTransactionResult *)downloadTrack:(Track *)track
 {
+	NSLog(@"enter downloadTrack");
 	// set turbo on/off
 	[self enableTurbo];
 	
@@ -460,6 +467,8 @@ StatusDisplayer *statusDisplayerGlobal;
 	// rate in Mbps
 	double rate = ((double)[track filesize] / time) * 8.0 / (1024.0 * 1024.0);
 	
+	NSLog(@"leave downloadTrack");
+	
 	return [[[NJBTransactionResult alloc] initWithSuccess:YES
 																					 resultString:[NSString stringWithFormat:NSLocalizedString(@"Speed %@ Mbps", nil), [self rateString:rate]]] autorelease];
 }
@@ -652,7 +661,7 @@ StatusDisplayer *statusDisplayerGlobal;
 
 - (BOOL)isProtocol3Device
 {
-	return (PROTOCOL3_DEVICE(njb->device_type));
+	return (PDE_PROTOCOL_DEVICE(njb));
 }
 
 - (NJBTransactionResult *)setOwnerString:(NSString *)owner
