@@ -51,8 +51,11 @@
 
 - (void)setResultString:(NSString *)newResultString
 {
+	if (newResultString == nil)
+		newResultString = @"";
 	// get immutable copy
-	newResultString = [newResultString copy];
+	newResultString = [NSString stringWithString:newResultString];
+	[newResultString retain];
 	[resultString release];
 	resultString = newResultString;
 }
