@@ -24,7 +24,7 @@
 		[self setArtist:@""];
 		[self setAlbum:@""];
 		[self setGenre:@""];
-		[self setFilename:@""];
+		//[self setFilename:@""];
 		[self setFullPath:@""];
 		[self setTrackNumber:0];
 		[self setYear:0];
